netapp_ontap.models.vsi_on_san_new_igroups API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.vsi_on_san_new_igroups`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class VsiOnSanNewIgroupsSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the VsiOnSanNewIgroups object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `comment: str POST PATCH`

    A comment available for use by the administrator.

  `igroups: List[MongoDbOnSanNewIgroupsIgroups] POST PATCH`

    The igroups field of the vsi_on_san_new_igroups.

  `initiator_objects: List[MongoDbOnSanNewIgroupsInitiatorObjects] POST PATCH`

    The initiator_objects field of the vsi_on_san_new_igroups.

  `initiators: List[str] GET POST PATCH`

    The initiators field of the vsi_on_san_new_igroups.

  `name: str POST PATCH`

    The name of the new initiator group.

  `protocol: str POST PATCH`

    The protocol of the new initiator group.

    Valid choices:

    - fcp
    - iscsi
    - mixed